﻿using System; // we need some usings to get use started
using System.Diagnostics;
using MatterHackers.Csg; // our constructive solid geometry base classes
using MatterHackers.Csg.Solids;
using MatterHackers.Csg.Transform;
using MatterHackers.Csg.Processors;
using MatterHackers.VectorMath; // helper math functions

namespace SimplePartScripting
{
    static class SimplePartTester
    {
        static CsgObject TrackConnecor()
        {
            // CsgObject is our base class for all constructive solid geometry primitives
            CsgObject total;

            // we create a box object and name it 'link'
            CsgObject bar = new Box(20, 5.8, 12, "link");

            // we set it's center to the center of the coordinate system
            bar = new SetCenter(bar, Vector3.Zero);
            // and we make the total = the only object we have at this time
            total = bar;
            // now we make a cyliner for the side
            CsgObject leftHold = new Cylinder(11.7 / 2, 12, Alignment.z);
            // position it where we want it
            leftHold = new SetCenter(leftHold, bar.GetCenter() + new Vector3(12, 0, 0));
            // and make another one on the other side by mirroring
            CsgObject rightHold = leftHold.NewMirrorAccrossX();
            // this is the way we actuall decide what boolean operation to put them together with
            total += leftHold; 
            total += rightHold;

            return total;  // and pass it back to the caller
        }

        static void Main()
        {
            // an internal function to save as an .scad file
            OpenSCadOutput.Save(TrackConnecor(), "TrackConnector.scad"); 
        }
    }
}